Enumeration
ClutterBoxAlignment
since: 1.2
Description [src]
The alignment policies available on each axis of the ClutterBoxLayout.
Available since: 1.2
Members
| Name | Description |
|---|---|
CLUTTER_BOX_ALIGNMENT_START |
Align the child to the top or to to the left, depending on the used axis. |
CLUTTER_BOX_ALIGNMENT_END |
Align the child to the bottom or to the right, depending on the used axis. |
CLUTTER_BOX_ALIGNMENT_CENTER |
Align the child to the center. |