Struct
ClutterColor
Description [src]
struct ClutterColor {
guint8 red;
guint8 green;
guint8 blue;
guint8 alpha;
}
Color representation.
Structure members
redRed component, between 0 and 255
greenGreen component, between 0 and 255
blueBlue component, between 0 and 255
alphaAlpha component, between 0 and 255
Functions
clutter_color_from_hls
Converts a color expressed in HLS (hue, luminance and saturation)
values into a ClutterColor.
clutter_color_from_pixel
Converts pixel from the packed representation of a four 8 bit channel
color to a ClutterColor.
clutter_color_from_string
Parses a string definition of a color, filling the ClutterColor.red,
ClutterColor.green, ClutterColor.blue and ClutterColor.alpha fields
of color.
since: 1.0
Instance methods
clutter_color_copy
Makes a copy of the color structure. The result must be freed using clutter_color_free().
since: 0.2
clutter_color_interpolate
Interpolates between initial and final ClutterColors
using progress.
since: 1.6
clutter_color_to_pixel
Converts color into a packed 32 bit integer, containing
all the four 8 bit channels used by ClutterColor.
clutter_color_to_string
Returns a textual specification of color in the hexadecimal form
since: 0.2